@@ -13,6 +13,7 @@
 // them out is good even when redundant
 #![allow(clippy::needless_lifetimes)]
 
+mod macro_impls;
 pub mod trait_hack;
 mod yoke;
 mod yokeable;
@@ -21,6 +22,9 @@ mod zero_copy_from;
 #[cfg(feature = "serde")]
 mod serde;
 
+#[cfg(feature = "derive")]
+pub use yoke_derive::{Yokeable, ZeroCopyFrom};
+
 pub use crate::yoke::{CloneableCart, Yoke};
 pub use crate::yokeable::Yokeable;
 pub use crate::zero_copy_from::ZeroCopyFrom;
